@@ -1,5 +1,5 @@
 /*
-** $Id: client.js,v 1.54 2008-04-10 09:48:25 jakub Exp $
+** $Id: client.js,v 1.60 2009-10-12 09:22:36 jakub Exp $
 ** Pazpar2's javascript client .
 */
 
@@ -53,6 +53,9 @@ curState.sort = confSort;
 curState.perPage = Number(confShowPerPage);
 curState.page = 0;
 
+curMaxRecs = 100;
+curMaxRecsCount = 1;
+
 
 var resFilters = new mkFilter();
 
@@ -381,6 +384,20 @@ function my_onbytarget(data){}
 ********************************************************************************
 */
 
+function clone(obj) {
+  if(obj == null || typeof(obj) != 'object') return obj;
+
+  if(obj.constructor == Array) {
+    var temp = [];
+    for(var i = 0; i < obj.length; i++) temp.push(clone(obj[i]));
+    return temp;
+  }
+
+  var temp = {};
+  for(var key in obj) temp[key] = clone(obj[key]);
+  return temp;
+}
+
 function copyObjProperties (newObj, stateObj)
 {
     for( var property in stateObj ) {
@@ -413,7 +430,8 @@ function historyHandler ( stateJSON )
                     curState.sort,
                     curState.getSingleFilterString() 
                     || resFilters.getFilterString(),
-                    curState.page * curState.perPage );
+                    curState.page * curState.perPage,
+                    {'maxrecs': curMaxRecs * curMaxRecsCount});
                 break;
             case 'show' :
                 if (gotResults) {
@@ -436,8 +454,14 @@ function showPage (pageNum)
     //curState.page = pageNum;
 }
 
+function fetchMore () {
+  curMaxRecsCount++;
+  fireSearch();
+}
+
 function onFormSubmitEventHandler() 
 {
+    curMaxRecsCount = 1;
     // load query and clear filter
     loadQueryFromForm();
     curState.clearSingleFilter();
@@ -534,6 +558,24 @@ function drawDetailedRecWithXsl(detailBox)
         ourlNode[0].firstChild.nodeValue = ourl;
     }
 
+    var rawLink = "?command=record&id="+
+      encodeURIComponent(currentDetailedId) + "&offset=";
+    var sourceFormat = currentDetailedData.xmlDoc
+      .getElementsByTagName('md-source-transform');
+    var sf = "marc21";
+    var txt;
+    if (sourceFormat.length && 
+        (txt = Element_getTextContent(sourceFormat[0]))) {
+      sf = txt;
+    }
+    var edLink = "?command=record&transformto="+sf+"_to_endnote&id=" +
+      encodeURIComponent(currentDetailedId) + "&offset=";
+    var locs = currentDetailedData.xmlDoc.getElementsByTagName('location');
+    for (var i=0; i<locs.length; i++) {
+      Element_appendTextNode(locs[i], 'md-raw-link', rawLink + i);
+      Element_appendTextNode(locs[i], 'md-endnote-link', edLink + i);
+    }
+
     Element_appendTransformResult ( detailBox[0], 
             currentDetailedData.xmlDoc,
             currentDetailedData.xslDoc );
@@ -554,6 +596,14 @@ function refine(field, value, opt)
     fireSearch();
 }
 
+function execRandomSearch(query) {
+  curState.reset();
+  document.search.query.value = query;
+  curState.simpleQuery = query;
+  if (advancedOn) toggleAdvanced();
+  fireSearch();
+}
+
 function redirect(field, value, opt)
 {
     curState.reset();
@@ -634,18 +684,26 @@ function drawPager(max, hits, active)
     var pager = $('div.pages');
     pager.empty();
 
-    if ( active )
+    if (active)
         showIndicator(results);
-    else if ( hits )
+    else if (hits)
         results.append(msg['completed']);
 
-    if ( hits )
+    if (hits) {
         results.append(' ' + lang["displaying"]+': <b>'
                         +firstOnPage+'</b> - <b>'+lastOnPage
                         +'</b> / <b>'+max
-                        +'</b> ( '+lang["totalhits"]+': '+hits+' )');
-    else
+                        +'</b> ('+lang["totalhits"]+': '+hits+') ');
+        if (max < hits) {
+          results.append('[');
+          $('<a href="more">'+lang['fetchmore'] +'</a>')
+            .click(function () { fetchMore(); return false; } )
+            .appendTo(results);
+          results.append(']');
+        }
+    } else {
         results.append(msg["completed"] + ' ' + msg["norecords"]);
+    }
     
     if ( curState.page > 0 ){
         $('<a href="prev" class="previous_active">'
